@@ -5,5 +5,6 @@ __email__ = "vananh@tinhte.vn"
 
 #TOP-LEVEL MODULES
 from vn_helper.text_preprocessing import text_preprocessing
+from vn_helper.num_preprocessing import num_preprocessing
 
-__all__ = ['text_preprocessing']
+__all__ = ['text_preprocessing', 'num_preprocessing']
